All of lore.kernel.org
 help / color / mirror / Atom feed
From: Jamey Hicks <jamey.hicks@hp.com>
To: mochel@osdl.org
Cc: linux-kernel@vger.kernel.org
Subject: PATCH: rename legacy bus to platform bus
Date: Thu, 23 Oct 2003 11:11:00 -0400	[thread overview]
Message-ID: <3F97EF84.2060901@hp.com> (raw)

[-- Attachment #1: Type: text/plain, Size: 434 bytes --]


Many of us, especially in the embedded computing world, think that 
"legacy bus" is a misnomer.  It's not going away.  What do root PCI 
buses connect to?  At the root of the device tree there is a bus.  This 
patch changes the name from legacy bus to platform bus.  I'm hoping this 
change can be made even this late in the development cycle.  It is a 
pretty small patch but I think that naming is very important.

-Jamey Hicks




[-- Attachment #2: platform-bus.patch --]
[-- Type: text/plain, Size: 2737 bytes --]

--- linux-2.6.0-test8-rmk1/drivers/base/platform.c	2003-09-27 20:50:09.000000000 -0400
+++ kernel26/drivers/base/platform.c	2003-10-23 10:50:03.226877352 -0400
@@ -14,8 +14,8 @@
 #include <linux/module.h>
 #include <linux/init.h>
 
-struct device legacy_bus = {
-	.bus_id		= "legacy",
+struct device platform_bus = {
+	.bus_id		= "platform",
 };
 
 /**
@@ -29,7 +29,7 @@
 		return -EINVAL;
 
 	if (!pdev->dev.parent)
-		pdev->dev.parent = &legacy_bus;
+		pdev->dev.parent = &platform_bus;
 
 	pdev->dev.bus = &platform_bus_type;
 	
@@ -105,12 +105,12 @@
 
 int __init platform_bus_init(void)
 {
-	device_register(&legacy_bus);
+	device_register(&platform_bus);
 	return bus_register(&platform_bus_type);
 }
 
-EXPORT_SYMBOL(legacy_bus);
+EXPORT_SYMBOL(platform_bus);
 EXPORT_SYMBOL(platform_bus_type);
 EXPORT_SYMBOL(platform_device_register);
 EXPORT_SYMBOL(platform_device_unregister);
--- linux-2.6.0-test8-rmk1/drivers/i2c/i2c-dev.c	2003-10-19 23:23:05.000000000 -0400
+++ kernel26/drivers/i2c/i2c-dev.c	2003-10-23 10:52:08.964762288 -0400
@@ -447,8 +447,8 @@
 
 	/* register this i2c device with the driver core */
 	i2c_dev->adap = adap;
-	if (adap->dev.parent == &legacy_bus)
+	if (adap->dev.parent == &platform_bus)
 		i2c_dev->class_dev.dev = &adap->dev;
 	else
 		i2c_dev->class_dev.dev = adap->dev.parent;
--- linux-2.6.0-test8-rmk1/drivers/scsi/hosts.c	2003-09-27 20:50:07.000000000 -0400
+++ kernel26/drivers/scsi/hosts.c	2003-10-23 10:52:20.152061560 -0400
@@ -111,8 +111,8 @@
 	}
 
 	if (!shost->shost_gendev.parent)
-		shost->shost_gendev.parent = dev ? dev : &legacy_bus;
+		shost->shost_gendev.parent = dev ? dev : &platform_bus;
 
 	error = device_add(&shost->shost_gendev);
 	if (error)
--- linux-2.6.0-test8-rmk1/include/linux/device.h	2003-10-19 23:23:11.000000000 -0400
+++ kernel26/include/linux/device.h	2003-10-23 10:56:56.250088280 -0400
@@ -372,7 +372,7 @@
 extern void platform_device_unregister(struct platform_device *);
 
 extern struct bus_type platform_bus_type;
-extern struct device legacy_bus;
+extern struct device platform_bus;
 
 /* drivers/base/power.c */
 extern void device_shutdown(void);

             reply	other threads:[~2003-10-23 15:11 UTC|newest]

Thread overview: 5+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2003-10-23 15:11 Jamey Hicks [this message]
2003-10-24  6:51 ` PATCH: rename legacy bus to platform bus H. Peter Anvin
2003-10-27 22:46 ` Patrick Mochel
2003-10-28 18:12   ` Jamey Hicks
2003-10-28 18:24     ` Patrick Mochel

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=3F97EF84.2060901@hp.com \
    --to=jamey.hicks@hp.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mochel@osdl.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.
--- linux-2.6.0-test8-rmk1/drivers/i2c/i2c-core.c	2003-09-27 20:50:10.000000000 -0400
+++ kernel26/drivers/i2c/i2c-core.c	2003-10-23 10:51:52.070330632 -0400
@@ -136,11 +136,11 @@
 
 	/* Add the adapter to the driver core.
 	 * If the parent pointer is not set up,
 	 * we add this adapter to the legacy bus.
 	 */
 	if (adap->dev.parent == NULL)
-		adap->dev.parent = &legacy_bus;
+		adap->dev.parent = &platform_bus;
 	sprintf(adap->dev.bus_id, "i2c-%d", adap->nr);
 	adap->dev.driver = &i2c_adapter_driver;
 	adap->dev.release = &i2c_adapter_dev_release;
@@ -136,11 +136,11 @@
 	/* Add the adapter to the driver core.
 	 * If the parent pointer is not set up,
-	 * we add this adapter to the legacy bus.
+	 * we add this adapter to the platform bus.
 	 */
 	if (adap->dev.parent == NULL)